==> mysql-connector-java-8.0.11-sources.jar: com/mysql/cj/log/ProfilerEventHandlerFactory.java <==
/*
 * Copyright (c) 2002, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 2.0, as published by the
 * Free Software Foundation.
 *
 * This program is also distributed with certain software (including but not
 * limited to OpenSSL) that is licensed under separate terms, as designated in a
 * particular file or component or in included license documentation. The
 * authors of MySQL hereby grant you an additional permission to link the
 * program and your derivative works with the separately licensed software that
 * they have included with MySQL.
 *
 * Without limiting anything contained in the foregoing, this file, which is
 * part of MySQL Connector/J, is also subject to the Universal FOSS Exception,
 * version 1.0, a copy of which can be found at
 * http://oss.oracle.com/licenses/universal-foss-exception.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License, version 2.0,
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */

package com.mysql.cj.log;

import com.mysql.cj.Session;
import com.mysql.cj.conf.PropertyDefinitions;
import com.mysql.cj.util.Util;

public class ProfilerEventHandlerFactory {

    /**
     * Returns the ProfilerEventHandler that handles profiler events for the given session.
     * 
     * @param sess
     *            the session to handle events for
     * @return the {@link ProfilerEventHandler} that handles profiler events
     */
    public static synchronized ProfilerEventHandler getInstance(Session sess) {
        ProfilerEventHandler handler = sess.getProfilerEventHandler();

        if (handler == null) {
            handler = (ProfilerEventHandler) Util.getInstance(
                    sess.getPropertySet().getStringReadableProperty(PropertyDefinitions.PNAME_profilerEventHandler).getStringValue(), new Class<?>[0],
                    new Object[0], sess.getExceptionInterceptor());

            handler.init(sess.getLog());
            sess.setProfilerEventHandler(handler);
        }

        return handler;
    }

    public static synchronized void removeInstance(Session sess) {
        ProfilerEventHandler handler = sess.getProfilerEventHandler();

        if (handler != null) {
            handler.destroy();
        }
    }

}

==> mysql-connector-java-8.0.16-sources.jar: com/mysql/cj/log/ProfilerEventHandlerFactory.java <==
/*
 * Copyright (c) 2002, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 2.0, as published by the
 * Free Software Foundation.
 *
 * This program is also distributed with certain software (including but not
 * limited to OpenSSL) that is licensed under separate terms, as designated in a
 * particular file or component or in included license documentation. The
 * authors of MySQL hereby grant you an additional permission to link the
 * program and your derivative works with the separately licensed software that
 * they have included with MySQL.
 *
 * Without limiting anything contained in the foregoing, this file, which is
 * part of MySQL Connector/J, is also subject to the Universal FOSS Exception,
 * version 1.0, a copy of which can be found at
 * http://oss.oracle.com/licenses/universal-foss-exception.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License, version 2.0,
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */

package com.mysql.cj.log;

import com.mysql.cj.Session;
import com.mysql.cj.conf.PropertyKey;
import com.mysql.cj.util.Util;

public class ProfilerEventHandlerFactory {

    /**
     * Returns the ProfilerEventHandler that handles profiler events for the given session.
     * 
     * @param sess
     *            the session to handle events for
     * @return the {@link ProfilerEventHandler} that handles profiler events
     */
    public static synchronized ProfilerEventHandler getInstance(Session sess) {
        ProfilerEventHandler handler = sess.getProfilerEventHandler();

        if (handler == null) {
            handler = (ProfilerEventHandler) Util.getInstance(sess.getPropertySet().getStringProperty(PropertyKey.profilerEventHandler).getStringValue(),
                    new Class<?>[0], new Object[0], sess.getExceptionInterceptor());

            handler.init(sess.getLog());
            sess.setProfilerEventHandler(handler);
        }

        return handler;
    }

    public static synchronized void removeInstance(Session sess) {
        ProfilerEventHandler handler = sess.getProfilerEventHandler();

        if (handler != null) {
            handler.destroy();
        }
    }

}
